@@ -260,6 +260,12 @@ execute_dataset_format = '''
 def S_{filename}():
     dataset('{filename}','{param}','{remark}',{tolist})
 '''
+# check starrocks routine job
+execute_routinestarrocks_format = '''
+# execute dataset script
+def S_{filename}():
+    routineStarrocks('{label}','{flag}')
+'''
 
 # check dataset
 execute_dash_format = '''
