@@ -26,6 +26,8 @@ DRIVES = {
     'hive_sql': {'color': '#9486ba', 't': 'sql'},
     'gp_sql': {'color': '#cecadb', 't': 'sql'},
     'mysql_sql': {'color': '#74946e', 't': 'sql'},
+    'oracle_sql': {'color': '#74946e', 't': 'sql'},
+    'mssql_sql': {'color': '#74946e', 't': 'sql'},
     'starrocks_sql': {'color': '#74946e', 't': 'sql'},
     'sqoop': {'color': '#665908', 't': 'sql'},
     'sap': {'color': '#f4a460', 't': 'json'},
@@ -37,7 +39,8 @@ DRIVES = {
     'dataxx': {'color': '#4675df', 't': 'json'},
     'refresh_smc': {'color': '#6675df'},
     'hdfsstarrocks': {'color': '#665998', 't': 'sql'},
-    'kafkastarrocks': {'color': '#365998', 't': 'sql'},
+    'kafkastarrocks': {'color': '#e8a6a6', 't': 'sql'},
+    'routinestarrocks': {'color': '#b4a7d6'},
 }
 
 
@@ -163,6 +166,8 @@ def gen_airflow_dag(*args, **kwargs):
             etl_str = etl_str + execute_datax_format.format(project_name=project_name, filename=item[1], param=item[2])
         elif driver == 'kafkastarrocks':
             etl_str = etl_str + execute_kafkastarrocks_format.format(project_name=project_name, filename=item[1], param=item[2])
+        elif driver == 'routinestarrocks':
+            etl_str = etl_str + execute_routinestarrocks_format.format(filename=item[1], label=item[2], flag=item[3])
         elif driver == 'dataxx':
             etl_str = etl_str + execute_dataxx_format.format(project_name=project_name, filename=item[1], param=item[2])
         elif driver == 'sap':
